@@ -8,10 +8,10 @@ use super::{Extension, FromRequest, RequestParts};
 use crate::{AddExtension, AddExtensionLayer};
 use async_trait::async_trait;
 use hyper::server::conn::AddrStream;
-use std::future::ready;
 use std::{
     convert::Infallible,
     fmt,
+    future::ready,
     marker::PhantomData,
     net::SocketAddr,
     task::{Context, Poll},
@@ -32,7 +32,7 @@ pub struct IntoMakeServiceWithConnectInfo<S, C> {
 
 #[test]
 fn traits() {
-    use crate::tests::*;
+    use crate::test_helpers::*;
     assert_send::<IntoMakeServiceWithConnectInfo<(), NotSendSync>>();
 }
 
@@ -56,6 +56,18 @@ where
     }
 }
 
+impl<S, C> Clone for IntoMakeServiceWithConnectInfo<S, C>
+where
+    S: Clone,
+{
+    fn clone(&self) -> Self {
+        Self {
+            svc: self.svc.clone(),
+            _connect_info: PhantomData,
+        }
+    }
+}
+
 /// Trait that connected IO resources implement and use to produce information
 /// about the connection.
 ///
@@ -132,8 +144,7 @@ where
 #[cfg(test)]
 mod tests {
     use super::*;
-    use crate::Server;
-    use crate::{routing::get, Router};
+    use crate::{routing::get, Router, Server};
     use std::net::{SocketAddr, TcpListener};
 
     #[tokio::test]
