@@ -1,5 +1,4 @@
-use crate::routing::UrlParams;
-use crate::util::ByteStr;
+use crate::util::{ByteStr, PercentDecodedByteStr};
 use serde::{
     de::{self, DeserializeSeed, EnumAccess, Error, MapAccess, SeqAccess, VariantAccess, Visitor},
     forward_to_deserialize_any, Deserializer,
@@ -53,20 +52,20 @@ macro_rules! parse_single_value {
         where
             V: Visitor<'de>,
         {
-            if self.url_params.0.len() != 1 {
+            if self.url_params.len() != 1 {
                 return Err(PathDeserializerError::custom(
                     format!(
                         "wrong number of parameters: {} expected 1",
-                        self.url_params.0.len()
+                        self.url_params.len()
                     )
                     .as_str(),
                 ));
             }
 
-            let value = self.url_params.0[0].1.parse().map_err(|_| {
+            let value = self.url_params[0].1.parse().map_err(|_| {
                 PathDeserializerError::custom(format!(
                     "can not parse `{:?}` to a `{}`",
-                    self.url_params.0[0].1.as_str(),
+                    self.url_params[0].1.as_str(),
                     $tp
                 ))
             })?;
@@ -76,12 +75,12 @@ macro_rules! parse_single_value {
 }
 
 pub(crate) struct PathDeserializer<'de> {
-    url_params: &'de UrlParams,
+    url_params: &'de [(ByteStr, PercentDecodedByteStr)],
 }
 
 impl<'de> PathDeserializer<'de> {
     #[inline]
-    pub(crate) fn new(url_params: &'de UrlParams) -> Self {
+    pub(crate) fn new(url_params: &'de [(ByteStr, PercentDecodedByteStr)]) -> Self {
         PathDeserializer { url_params }
     }
 }
@@ -100,10 +99,12 @@ impl<'de> Deserializer<'de> for PathDeserializer<'de> {
     parse_single_value!(deserialize_i16, visit_i16, "i16");
     parse_single_value!(deserialize_i32, visit_i32, "i32");
     parse_single_value!(deserialize_i64, visit_i64, "i64");
+    parse_single_value!(deserialize_i128, visit_i128, "i128");
     parse_single_value!(deserialize_u8, visit_u8, "u8");
     parse_single_value!(deserialize_u16, visit_u16, "u16");
     parse_single_value!(deserialize_u32, visit_u32, "u32");
     parse_single_value!(deserialize_u64, visit_u64, "u64");
+    parse_single_value!(deserialize_u128, visit_u128, "u128");
     parse_single_value!(deserialize_f32, visit_f32, "f32");
     parse_single_value!(deserialize_f64, visit_f64, "f64");
     parse_single_value!(deserialize_string, visit_string, "String");
@@ -114,13 +115,13 @@ impl<'de> Deserializer<'de> for PathDeserializer<'de> {
     where
         V: Visitor<'de>,
     {
-        if self.url_params.0.len() != 1 {
+        if self.url_params.len() != 1 {
             return Err(PathDeserializerError::custom(format!(
                 "wrong number of parameters: {} expected 1",
-                self.url_params.0.len()
+                self.url_params.len()
             )));
         }
-        visitor.visit_str(&self.url_params.0[0].1)
+        visitor.visit_str(&self.url_params[0].1)
     }
 
     fn deserialize_unit<V>(self, visitor: V) -> Result<V::Value, Self::Error>
@@ -157,7 +158,7 @@ impl<'de> Deserializer<'de> for PathDeserializer<'de> {
         V: Visitor<'de>,
     {
         visitor.visit_seq(SeqDeserializer {
-            params: &self.url_params.0,
+            params: self.url_params,
         })
     }
 
@@ -165,18 +166,18 @@ impl<'de> Deserializer<'de> for PathDeserializer<'de> {
     where
         V: Visitor<'de>,
     {
-        if self.url_params.0.len() < len {
+        if self.url_params.len() < len {
             return Err(PathDeserializerError::custom(
                 format!(
                     "wrong number of parameters: {} expected {}",
-                    self.url_params.0.len(),
+                    self.url_params.len(),
                     len
                 )
                 .as_str(),
             ));
         }
         visitor.visit_seq(SeqDeserializer {
-            params: &self.url_params.0,
+            params: self.url_params,
         })
     }
 
@@ -189,18 +190,18 @@ impl<'de> Deserializer<'de> for PathDeserializer<'de> {
     where
         V: Visitor<'de>,
     {
-        if self.url_params.0.len() < len {
+        if self.url_params.len() < len {
             return Err(PathDeserializerError::custom(
                 format!(
                     "wrong number of parameters: {} expected {}",
-                    self.url_params.0.len(),
+                    self.url_params.len(),
                     len
                 )
                 .as_str(),
             ));
         }
         visitor.visit_seq(SeqDeserializer {
-            params: &self.url_params.0,
+            params: self.url_params,
         })
     }
 
@@ -209,7 +210,7 @@ impl<'de> Deserializer<'de> for PathDeserializer<'de> {
         V: Visitor<'de>,
     {
         visitor.visit_map(MapDeserializer {
-            params: &self.url_params.0,
+            params: self.url_params,
             value: None,
         })
     }
@@ -235,21 +236,21 @@ impl<'de> Deserializer<'de> for PathDeserializer<'de> {
     where
         V: Visitor<'de>,
     {
-        if self.url_params.0.len() != 1 {
+        if self.url_params.len() != 1 {
             return Err(PathDeserializerError::custom(format!(
                 "wrong number of parameters: {} expected 1",
-                self.url_params.0.len()
+                self.url_params.len()
             )));
         }
 
         visitor.visit_enum(EnumDeserializer {
-            value: &self.url_params.0[0].1,
+            value: &self.url_params[0].1,
         })
     }
 }
 
 struct MapDeserializer<'de> {
-    params: &'de [(ByteStr, ByteStr)],
+    params: &'de [(ByteStr, PercentDecodedByteStr)],
     value: Option<&'de str>,
 }
 
@@ -311,7 +312,7 @@ impl<'de> Deserializer<'de> for KeyDeserializer<'de> {
     }
 
     forward_to_deserialize_any! {
-        bool i8 i16 i32 i64 u8 u16 u32 u64 f32 f64 char bytes
+        bool i8 i16 i32 i64 i128 u8 u16 u32 u64 u128 f32 f64 char bytes
         byte_buf option unit unit_struct seq tuple
         tuple_struct map newtype_struct struct enum ignored_any
     }
@@ -351,10 +352,12 @@ impl<'de> Deserializer<'de> for ValueDeserializer<'de> {
     parse_value!(deserialize_i16, visit_i16, "i16");
     parse_value!(deserialize_i32, visit_i32, "i16");
     parse_value!(deserialize_i64, visit_i64, "i64");
+    parse_value!(deserialize_i128, visit_i128, "i128");
     parse_value!(deserialize_u8, visit_u8, "u8");
     parse_value!(deserialize_u16, visit_u16, "u16");
     parse_value!(deserialize_u32, visit_u32, "u32");
     parse_value!(deserialize_u64, visit_u64, "u64");
+    parse_value!(deserialize_u128, visit_u128, "u128");
     parse_value!(deserialize_f32, visit_f32, "f32");
     parse_value!(deserialize_f64, visit_f64, "f64");
     parse_value!(deserialize_string, visit_string, "String");
@@ -519,7 +522,7 @@ impl<'de> VariantAccess<'de> for UnitVariant {
 }
 
 struct SeqDeserializer<'de> {
-    params: &'de [(ByteStr, ByteStr)],
+    params: &'de [(ByteStr, PercentDecodedByteStr)],
 }
 
 impl<'de> SeqAccess<'de> for SeqDeserializer<'de> {
@@ -561,18 +564,16 @@ mod tests {
         a: i32,
     }
 
-    fn create_url_params<I, K, V>(values: I) -> UrlParams
+    fn create_url_params<I, K, V>(values: I) -> Vec<(ByteStr, PercentDecodedByteStr)>
     where
         I: IntoIterator<Item = (K, V)>,
         K: AsRef<str>,
         V: AsRef<str>,
     {
-        UrlParams(
-            values
-                .into_iter()
-                .map(|(k, v)| (ByteStr::new(k), ByteStr::new(v)))
-                .collect(),
-        )
+        values
+            .into_iter()
+            .map(|(k, v)| (ByteStr::new(k), PercentDecodedByteStr::new(v).unwrap()))
+            .collect()
     }
 
     macro_rules! check_single_value {
@@ -594,13 +595,16 @@ mod tests {
         check_single_value!(i16, "-123", -123);
         check_single_value!(i32, "-123", -123);
         check_single_value!(i64, "-123", -123);
+        check_single_value!(i128, "123", 123);
         check_single_value!(u8, "123", 123);
         check_single_value!(u16, "123", 123);
         check_single_value!(u32, "123", 123);
         check_single_value!(u64, "123", 123);
+        check_single_value!(u128, "123", 123);
         check_single_value!(f32, "123", 123.0);
         check_single_value!(f64, "123", 123.0);
         check_single_value!(String, "abc", "abc");
+        check_single_value!(String, "one%20two", "one two");
         check_single_value!(char, "a", 'a');
 
         let url_params = create_url_params(vec![("a", "B")]);
