@@ -19,7 +19,7 @@ pub struct IntoService<H, B, T> {
 
 #[test]
 fn traits() {
-    use crate::tests::*;
+    use crate::test_helpers::*;
     assert_send::<IntoService<(), NotSendSync, NotSendSync>>();
     assert_sync::<IntoService<(), NotSendSync, NotSendSync>>();
 }
@@ -64,9 +64,9 @@ where
 
     #[inline]
     fn poll_ready(&mut self, _cx: &mut Context<'_>) -> Poll<Result<(), Self::Error>> {
-        // `IntoService` can only be constructed from async functions which are always ready, or from
-        // `Layered` which bufferes in `<Layered as Handler>::call` and is therefore also always
-        // ready.
+        // `IntoService` can only be constructed from async functions which are always ready, or
+        // from `Layered` which bufferes in `<Layered as Handler>::call` and is therefore
+        // also always ready.
         Poll::Ready(Ok(()))
     }
 
