@@ -4,8 +4,6 @@ use http::Method;
 bitflags! {
     /// A filter that matches one or more HTTP methods.
     pub struct MethodFilter: u16 {
-        /// Match `CONNECT` requests.
-        const CONNECT = 0b000000001;
         /// Match `DELETE` requests.
         const DELETE =  0b000000010;
         /// Match `GET` requests.
@@ -29,7 +27,6 @@ impl MethodFilter {
     #[allow(clippy::match_like_matches_macro)]
     pub(crate) fn matches(self, method: &Method) -> bool {
         let method = match *method {
-            Method::CONNECT => Self::CONNECT,
             Method::DELETE => Self::DELETE,
             Method::GET => Self::GET,
             Method::HEAD => Self::HEAD,
